@@ -23,8 +23,9 @@
 #include <avogadro/qtplugins/pluginmanager.h>
 #include <avogadro/rendering/primitive.h>
 
-#include <QWidget>
+#include <QDebug>
 #include <QSettings>
+#include <QWidget>
 
 #include <config-kalzium.h>
 
@@ -57,7 +58,7 @@ KalziumGLWidget::KalziumGLWidget(QWidget *parent)
     foreach (auto *factory, scenePluginFactories) {
         auto *scenePlugin = factory->createInstance();
         // enable Ball-and-Sticks
-        if (scenePlugin->objectName() == "BallStick") {
+        if (scenePlugin->objectName() == QLatin1String("BallStick")) {
             scenePlugin->setEnabled(true);
         }
         sceneModel().addItem(scenePlugin);
