@@ -7,7 +7,7 @@
  Copyright (C) 2010 by Etienne Rebetez etienne.rebetez@oberwallis.ch
 
  This file is part of the Avogadro molecular editor project.
- For more information, see <http://avogadro.openmolecules.net/>
+ For more information, see <https://avogadro.cc/>
 
  Avogadro is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
@@ -29,22 +29,22 @@
 #include "elementitem.h"
 
 #include <prefs.h>
-#include <KLocalizedString>
 
+#include <QDebug>
+#include <QFont>
+#include <QFontMetrics>
 #include <QGraphicsSceneMouseEvent>
 #include <QPainter>
 #include <QStyleOption>
-#include <QFont>
-#include <QFontMetrics>
-#include <QDebug>
 
+#include <KLocalizedString>
 
 ElementItem::ElementItem(KalziumElementProperty *elProperty, int elementNumber) : m_width(40),
     m_height(40), m_element(elementNumber), m_property(elProperty)
 {
     // Want these items to be selectable
     setFlags(QGraphicsItem::ItemIsSelectable);
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 
     m_symbol = KalziumDataObject::instance()->element(m_element)->dataAsString(ChemicalDataObject::symbol);
 
@@ -142,7 +142,7 @@ void ElementItem::hoverEnterEvent(QGraphicsSceneHoverEvent* event)
 {
     setZValue(200);
     moveBy(-m_width / 4, -m_height / 4);
-    scale(1.5, 1.5);
+    setScale(1.5);
     QGraphicsItem::hoverEnterEvent(event);
 }
 
@@ -151,6 +151,7 @@ void ElementItem::hoverLeaveEvent(QGraphicsSceneHoverEvent* event)
     resetTransform();
     moveBy(m_width / 4, m_height / 4);
     setZValue(100);
+    setScale(1);
     QGraphicsItem::hoverLeaveEvent(event);
 }
 
